@@ -324,13 +324,9 @@ class GraphButton(Button):
             return
 
         values = self.update(graph_size[0] - 2)
-        print(f"### RENDERING {self.label!r} ===================")
-        print(f"### GRAPH ASK FOR {graph_size[0] - 2} DATA POINTS")
         min_val = 9999
         max_val = -9999
-        print(f"### LOOPING OVER {len(values)} TRACES")
         for entry in values:
-            print(f"### ENTRY {entry}")
             data = entry["data"]
             if len(data) > 0:
                 min_val = entry.get("min", min(min_val, min(data)))
@@ -338,21 +334,17 @@ class GraphButton(Button):
             else:
                 min_val = 0
                 max_val = 0
-        print(f"### MIN {min_val}, MAX {max_val}")
 
         range = max_val - min_val
         if range < 1:
             min_val -= 1
             max_val += 1
             range = 2
-        print(f"### RANGE {range}")
 
         for entry in values:
-            print(f"### => {entry}")
             color = entry["color"]
             data = entry["data"]
 
-            print(f"### COLOR {color}, DATA {data}")
             def scale_y_value(value):
                 center_val = value - (range / 2)
                 return self.y + (self.h / 2 - (
@@ -364,16 +356,11 @@ class GraphButton(Button):
                 prev_x = graph_pos[0]
                 for val in data:
                     x = prev_x + 1
-                    print(f"### SCALE {val}...")
                     y = scale_y_value(val)
-                    print(f"### ... TO {y}")
                     pygame.draw.line(surface, color, (prev_x, prev_y), (x, y), 2)
                     prev_x = x
                     prev_y = y
 
-                print(f"### RENDER LAST VALUE")
-                print(f"### OF {data[-1]}")
-
                 text = self.graph_font.render(snapped_value_string(data[-1], 0.1),
                                               1,
                                               color)
